/* 
 * Blinky - a GTK network usage monitor
 *
 * Copyright (C) 2002, Benjamin Miller <bmiller@users.sf.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */


#ifndef _BLINKY_H
#define _BLINKY_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef HAVE_KSTAT
#include <kstat.h>
#endif
#include <gtk/gtk.h>


/* Global types */

typedef struct {
    char name[16];
    char tip[256];
    int tip_timer;
    unsigned long tx_cur, rx_cur;
    gboolean txing, rxing, up, found;
    GtkWidget *hbox, *eventbox;
#ifdef HAVE_KSTAT
    kstat_t *k;
#endif
} IFA;

typedef struct {
    int interval;
    GdkColor *ac, *ic, *dc;
    GdkGC *agc, *igc, *dgc;
    /* more to come */
} blinky_opts;


/* Global variables - blinky.c */
extern GtkWidget *mainbox;
extern GtkTooltips *tips;
extern GSList *ifs;
extern blinky_opts *options;


/* Functions in blinky.c */
GtkWidget *show_main_window (void);
void quit (GtkWidget *, gpointer);
/* Functions in util.c */
gboolean update_all (gpointer);
void get_usage_all (void);
void get_setup (int, char **);
GdkGC *color_to_gc (GtkWidget *, GdkColor *);
void format_bytes (unsigned long long, char *, int);
/* Functions in ifa.c */
IFA *ifa_new (const char[]);
void ifa_draw (GtkWidget *, GdkEvent *, IFA *);
void ifa_handle_click (GtkWidget *, GdkEventButton *, IFA *);
/* Functions in prefs.c */
void show_colorsel (GtkWidget *, int);
void apply_colorsel (GtkWidget *, int);
void delete_colorsel (GtkWidget *, int);


#endif /* _BLINKY_H */


/*
 * Local variables:
 * c-basic-offset: 4
 * End:
 */
