/* 
 * Blinky - a GTK network usage monitor
 *
 * Copyright (C) 2002, Benjamin Miller <bmiller@users.sf.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */


#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef HAVE_KSTAT
#include <kstat.h>
#endif
#include <string.h>
#include <gtk/gtk.h>
#include "blinky.h"


IFA *
ifa_new (const char name[])
{
    IFA *ifa = g_malloc (sizeof(IFA));

    if (ifa == NULL)
	return NULL;

    ifa->tx_cur = ifa->rx_cur = -1;
    ifa->tip_timer = 0;
    ifa->txing = ifa->rxing = FALSE;
    ifa->up = TRUE;
    strcpy (ifa->name, name);

    ifa->hbox = gtk_hbox_new(FALSE, 0);
    gtk_box_pack_start (GTK_BOX(mainbox), ifa->hbox, FALSE, FALSE, 0);
    gtk_widget_show(ifa->hbox);

    ifa->eventbox = gtk_event_box_new();
    gtk_box_pack_start (GTK_BOX(ifa->hbox), ifa->eventbox, 
			FALSE, FALSE, 0);
    gtk_widget_set_usize (ifa->eventbox, 41, 21);
    gtk_signal_connect_after (GTK_OBJECT(ifa->eventbox), "expose_event",
			      GTK_SIGNAL_FUNC(ifa_draw), ifa);
    gtk_signal_connect (GTK_OBJECT(ifa->eventbox), "button_press_event",
			GTK_SIGNAL_FUNC(ifa_handle_click), ifa);
    gtk_tooltips_set_tip (tips, ifa->eventbox, ifa->name, "");
    gtk_widget_show(ifa->eventbox);

#ifdef HAVE_KSTAT
    ifa->k = NULL;
#endif
    return ifa;
}


void
ifa_draw (GtkWidget *widget, GdkEvent *event, IFA *ifa)
{
    GdkColor line = {0x0, 0x0, 0x0};
    GdkColormap *cmap;
    GdkVisual *vis;
    GdkWindow *w = widget->window;
    static GdkGC *line_gc = NULL;
	
    if (options->agc == NULL)
	options->agc = color_to_gc (widget, options->ac);
    if (options->igc == NULL)
	options->igc = color_to_gc (widget, options->ic);
    if (options->dgc == NULL)
	options->dgc = color_to_gc (widget, options->dc);
	
    if (line_gc == NULL) {
	cmap = gtk_widget_get_colormap (widget);
	vis = gdk_colormap_get_visual (cmap);
	gdk_color_black (cmap, &line);
	line_gc = gdk_gc_new (w);
	gdk_gc_set_foreground (line_gc, &line);
    }

    /* draw the lights */
    if (ifa->up) {
	if (ifa->rxing)
	    gdk_draw_rectangle (w, options->agc, 1, 0, 0, 20, 20);
	else
	    gdk_draw_rectangle (w, options->igc, 1, 0, 0, 20, 20);
	if (ifa->txing)
	    gdk_draw_rectangle (w, options->agc, 1, 20, 0, 20, 20);
	else
	    gdk_draw_rectangle (w, options->igc, 1, 20, 0, 20, 20);
    } else
	gdk_draw_rectangle (w, options->dgc, 1, 0, 0, 40, 20);

    /* and the borders */
    gdk_draw_rectangle (w, line_gc, 0, 0, 0, 20, 20);
    gdk_draw_rectangle (w, line_gc, 0, 20, 0, 20, 20);
}


void
ifa_handle_click (GtkWidget *widget, GdkEventButton *event, IFA *ifa)
{
    static GtkWidget *menu = NULL;
    GtkWidget *item;
    char buf[32];

    if (event->type == GDK_BUTTON_PRESS && event->button == 3) {
	if (menu)
	    gtk_widget_destroy(menu);

	menu = gtk_menu_new();

	g_snprintf (buf, 32, "%s details", ifa->name);
	item = gtk_menu_item_new_with_label(buf);
	gtk_menu_append (GTK_MENU(menu), item);
	gtk_widget_show (item);

	item = gtk_menu_item_new_with_label("Select Active Color");
	gtk_menu_append (GTK_MENU(menu), item);
	gtk_signal_connect (GTK_OBJECT(item), "activate",
			    GTK_SIGNAL_FUNC(show_colorsel), (void *)1);
	gtk_widget_show (item);

	item = gtk_menu_item_new_with_label("Select Inactive Color");
	gtk_menu_append (GTK_MENU(menu), item);
	gtk_signal_connect (GTK_OBJECT(item), "activate",
			    GTK_SIGNAL_FUNC(show_colorsel), (void *)2);
	gtk_widget_show (item);

	item = gtk_menu_item_new_with_label("Select Down Color");
	gtk_menu_append (GTK_MENU(menu), item);
	gtk_signal_connect (GTK_OBJECT(item), "activate",
			    GTK_SIGNAL_FUNC(show_colorsel), (void *)3);
	gtk_widget_show (item);

	gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL, 
		       event->button, event->time);
    }
}


/*
 * Local variables:
 * c-basic-offset: 4
 * End:
 */
